Index: /trunk/src/VBox/HostServices/SharedClipboard/VBoxClipboard-win.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/VBoxClipboard-win.cpp	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedClipboard/VBoxClipboard-win.cpp	(revision 65123)
@@ -790,6 +790,7 @@
 }
 
-int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA *pClient, bool)
-{
+int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA *pClient, bool fHeadless)
+{
+    NOREF(fHeadless);
     Log(("vboxClipboardConnect\n"));
 
@@ -1047,5 +1048,7 @@
  * Check that the source string contains CF_HTML struct
  *
- * @returns @c true if the @source string is in CF_HTML format
+ * @param   pszSource   source string.
+ *
+ * @returns @c true if the @a pszSource string is in CF_HTML format
  */
 static bool IsWindowsHTML(const char *pszSource)
Index: /trunk/src/VBox/HostServices/SharedClipboard/darwin.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/darwin.cpp	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedClipboard/darwin.cpp	(revision 65123)
@@ -151,8 +151,10 @@
  *
  * @param   pClient Structure containing context information about the guest system
+ * @param   fHeadless Whether headless.
  * @returns RT status code
  */
-int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA *pClient, bool)
-{
+int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA *pClient, bool fHeadless)
+{
+    NOREF(fHeadless);
     if (g_ctx.pClient != NULL)
     {
Index: /trunk/src/VBox/HostServices/SharedClipboard/x11-clipboard.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/x11-clipboard.cpp	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedClipboard/x11-clipboard.cpp	(revision 65123)
@@ -250,13 +250,13 @@
  * @param  pCtx  request context information
  * @param  rc    the completion status of the request
- * @param  cbActual  on successful completion, the number of bytes of data
- *                   actually written, on buffer overflow the size of the
- *                   buffer needed, ignored otherwise
+ * @param  pReq  request
+ * @param  pv    address
+ * @param  cb    size
+ *
  * @todo   change this to deal with the buffer issues rather than offloading
  *         them onto the caller
  */
 void ClipCompleteDataRequestFromX11(VBOXCLIPBOARDCONTEXT *pCtx, int rc,
-                                    CLIPREADCBREQ *pReq, void *pv,
-                                    uint32_t cb)
+                                    CLIPREADCBREQ *pReq, void *pv, uint32_t cb)
 {
     if (cb <= pReq->cb)
Index: /trunk/src/VBox/HostServices/SharedFolders/vbsf.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedFolders/vbsf.cpp	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedFolders/vbsf.cpp	(revision 65123)
@@ -149,4 +149,5 @@
  * @param  fShflFlags shared folder create flags
  * @param  fMode      file attributes
+ * @param  handleInitial initial handle
  * @retval pfOpen     iprt create flags
  */
@@ -700,5 +701,6 @@
  *
  * @returns iprt status code (currently VINF_SUCCESS)
- * @param   pszFullPath    The path of the file to be looked up
+ * @param   pClient    client data
+ * @param   pszPath    The path of the file to be looked up
  * @retval  pParms->Result Status of the operation (success or error)
  * @retval  pParms->Info   On success, information returned about the file
@@ -757,4 +759,5 @@
 }
 #endif
+
 /**
  * Create or open a file or folder.  Perform character set and case
Index: /trunk/src/VBox/HostServices/SharedFolders/vbsfpath.h
===================================================================
--- /trunk/src/VBox/HostServices/SharedFolders/vbsfpath.h	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedFolders/vbsfpath.h	(revision 65123)
@@ -37,9 +37,5 @@
  * @param ppszHostPath           Returned full host path: root prefix + guest path.
  * @param pcbHostPathRoot        Length of the root prefix in bytes. Optional, can be NULL.
- * @param fWildCard              Whether the last component may contain
- *                               wildcards and thus might require exclusion
- *                               from the case correction.
- * @param fPreserveLastComponent Always exclude the last component from case
- *                               correction if set.
+ * @param fu32Options            Options.
  * @param pfu32PathFlags         VBSF_F_PATH_* flags. Optional, can be NULL.
  */
@@ -47,6 +43,5 @@
                         PSHFLSTRING pGuestString, uint32_t cbGuestString,
                         char **ppszHostPath, uint32_t *pcbHostPathRoot,
-                        uint32_t fu32Options,
-                        uint32_t *pfu32PathFlags);
+                        uint32_t fu32Options, uint32_t *pfu32PathFlags);
 
 /** Free the host path returned by vbsfPathGuestToHost.

Index: /trunk/src/VBox/HostServices/SharedClipboard/x11-stub.cpp
===================================================================
--- /trunk/src/VBox/HostServices/SharedClipboard/x11-stub.cpp	(revision 65122)
+++ /trunk/src/VBox/HostServices/SharedClipboard/x11-stub.cpp	(revision 65123)
@@ -49,10 +49,12 @@
   * Enable the shared clipboard - called by the hgcm clipboard subsystem.
   *
   * @param   pClient Structure containing context information about the guest system
   * @returns RT status code
   */
-int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA * /* pClient */,
-                          bool /* fHeadless */)
+int vboxClipboardConnect (VBOXCLIPBOARDCLIENTDATA *pClient,
+                          bool fHeadless)
 {
+    NOREF(pClient, fHeadless);
     LogFlowFunc(("called, returning VINF_SUCCESS.\n"));
     return VINF_SUCCESS;
@@ -71,7 +73,10 @@
 /**
  * Shut down the shared clipboard subsystem and "disconnect" the guest.
+ * 
+ * @param   pClient    Structure containing context information about the guest system
  */
-void vboxClipboardDisconnect (VBOXCLIPBOARDCLIENTDATA * /* pClient */)
+void vboxClipboardDisconnect (VBOXCLIPBOARDCLIENTDATA *pClient)
 {
+    NOREF(pClient);
     LogFlowFunc(("called, returning.\n"));
 }
@@ -84,7 +89,8 @@
  * @param u32Formats Clipboard formats the guest is offering
  */
-void vboxClipboardFormatAnnounce (VBOXCLIPBOARDCLIENTDATA * /* pClient */,
-                                  uint32_t /* u32Formats */)
+void vboxClipboardFormatAnnounce (VBOXCLIPBOARDCLIENTDATA *pClient,
+                                  uint32_t u32Formats)
 {
+    NOREF(pClient, u32Formats);
     LogFlowFunc(("called, returning.\n"));
 }
@@ -99,7 +105,8 @@
  * @param pcbActual Where to write the actual size of the written data
  */
-int vboxClipboardReadData (VBOXCLIPBOARDCLIENTDATA * /* pClient */, uint32_t /* u32Format */,
-                           void * /* pv */, uint32_t /* cb */, uint32_t * pcbActual)
+int vboxClipboardReadData (VBOXCLIPBOARDCLIENTDATA *pClient, uint32_t u32Format,
+                           void *pv, uint32_t cb, uint32_t *pcbActual)
 {
+    NOREF(pClient, u32Format, pv, cb);
     LogFlowFunc(("called, returning VINF_SUCCESS.\n"));
     /* No data available. */
@@ -116,7 +123,8 @@
  * @param u32Format The format of the data written
  */
-void vboxClipboardWriteData (VBOXCLIPBOARDCLIENTDATA * /* pClient */, void * /* pv */,
-                             uint32_t /* cb */, uint32_t /* u32Format */)
+void vboxClipboardWriteData (VBOXCLIPBOARDCLIENTDATA *pClient, void *pv,
+                             uint32_t cb, uint32_t u32Format)
 {
+    NOREF(pClient, pv, cb, u32Format);
     LogFlowFunc(("called, returning.\n"));
 }
@@ -49,10 +49,12 @@
   * Enable the shared clipboard - called by the hgcm clipboard subsystem.
   *
-  * @param   pClient Structure containing context information about the guest system
+  * @param   pClient    Structure containing context information about the guest system
+  * @param   fHeadless  Whether headless.
   * @returns RT status code
   */